<?php

namespace Ems\portalGestor\Service;

use Ems\portalGestor\Util\HcmServices;

class MarcacaoService {
    /** @var ParamOrgService */
    protected $paramOrgService;


    public function __construct(
        HcmServices $hcmServices,
        ParamOrgService $paramOrgService
    ) {
        $this->hcmServices = $hcmServices;
        $this->paramOrgService = $paramOrgService;
    }

    public function registraMarcacaoHcmServices($row) {
        $getVinculosDoGestorRoute = 'registraMarcacaoIntervalo';
        $nrOrg = (int) $row['NRORG'];
        $nrColetor = $this->paramOrgService->getNrColetorBatida($nrOrg);

        $result = $this->hcmServices->send(
            $getVinculosDoGestorRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRVINCULOM'    => $row['NRVINCULOM'],
                    'CDOPERADOR'    => $row['CDOPERADOR'],
                    'DSLATITUDE'    => $row['DSLATITUDE'],
                    'DSLONGITUDE'   => $row['DSLONGITUDE'],
                    'NRCOLETOR'     => $nrColetor,
                    'DSPATH'        => $row['DSPATH']
                )
            ),
            $nrOrg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['setMarcacaoIntervalo'];
    }

    public function registraMarcacaoAlmocoHcmServices($row) {
        $getVinculosDoGestorRoute = 'registraMarcacaoAlmoco';
        $nrOrg = (int) $row['NRORG'];
        $nrColetor = $this->paramOrgService->getNrColetorBatida($nrOrg);

        $result = $this->hcmServices->send(
            $getVinculosDoGestorRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRVINCULOM'    => $row['NRVINCULOM'],
                    'CDOPERADOR'    => $row['CDOPERADOR'],
                    'DSLATITUDE'    => $row['DSLATITUDE'],
                    'DSLONGITUDE'   => $row['DSLONGITUDE'],
                    'NRCOLETOR'     => $nrColetor,
                    'DSPATH'        => $row['DSPATH']
                )
            ),
            $nrOrg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['setMarcacaoAlmoco'];
    }

    public function insertAlmocoGestor(
        int $nrOrg,
        string $cdOperador,
        int $nrVinculo,
        string $date,
        int $nrMarcacao
    ): bool {

        $hcmServicesRoute = 'insertAlmocoGestor';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR'      => $cdOperador,
                'NRVINCULOM'      => $nrVinculo,
                'DATE'            => $date,
                'NRMARCACAOPONTO' => $nrMarcacao
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function insertAlmocoMultiplesGestor(
        int     $nrOrg,
        string  $cdOperador,
        int     $nrVinculo,
        array   $dates
    ): bool {

        $hcmServicesRoute = 'insertAlmocoMultiplesGestor';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM'        => $nrVinculo,
                'CDOPERADOR'        => $cdOperador,
                'DATE'              => $dates
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function removeAlmocoGestor(
        int $nrOrg,
        int $nrVinculo,
        string $date
    ): bool {

        $hcmServicesRoute = 'removeAlmocoGestor';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM' => $nrVinculo,
                'DATE'       => $date
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function getMarcacoesFotos(
        int $nrOrg,
        int $nrVinculo,
        string $date
    ): array {

        $hcmServicesRoute = 'getMarcacoesFotos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM' => $nrVinculo,
                'DATE'       => $date
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $filesData = $response['dataset'][$hcmServicesRoute];

        return $filesData;
    }

    public function setEntradasSaidasFixos  (
        $nrOrg,
        $nrVinculo,
        $cdOperador,
        $marcacoes
    ): array {
        $hcmServicesRoute = 'setEntradasSaidasFixos';

        $nrColetorGestor = $this->paramOrgService->getNrColetorGestor(
            $nrOrg
        );

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM'    => $nrVinculo,
                'CDOPERADOR'    => $cdOperador,
                'ROWS'          => $marcacoes,
                'NRCOLETOR'     => $nrColetorGestor,
            ],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $filesData = $response['dataset'][$hcmServicesRoute];

        return $filesData;
    }

    public function getDetalheAcompanhamento(
        int   $nrOrg,
        int   $nrVinculo,
        array $dates
    ): array {
        $route = 'getDetalheAcompanhamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM'    => $nrVinculo,
                'DATAAPURACAO'  => $dates,
            ]
        ];

        $response = $this->hcmServices->send($route, $params, $nrOrg);
        $marcacoes = $response['dataset'][$route];

        return $marcacoes;
    }

    public function removeMarcacao(
        int   $nrOrg,
        int   $nrVinculo,
        int   $nrMarcacao
    ): bool {
        $route = 'removeMarcacao';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM'        => $nrVinculo,
                'NRMARCACAOPONTO'   => $nrMarcacao,
            ],
        ];

        $response = $this->hcmServices->send($route, $params, $nrOrg);
        $success = isset($response['dataset']['marcacoesRemovidas']);

        return $success;
    }

    public function removeParesMarcacao(
        array $row
    ): array {
        $route = 'removeParesMarcacao';
        $nrOrg = (int) $row['NRORG'];

        $params = [
            'requestType' => 'Row',
            'row' => $row,
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $nrMarcacoes = $result['dataset']['marcacoesRemovidas'];

        return $nrMarcacoes;
    }

    public function editParesMarcacao(
        array $row
    ) : array {
        $route = 'editParesMarcacao';
        $nrOrg = (int) $row['NRORG'];

        $nrColetorGestor = $this->paramOrgService->getNrColetorGestor($nrOrg);
        $row['NRCOLETOR'] = $nrColetorGestor;

        $params = [
            'requestType' => 'Row',
            'row' => $row,
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $success = $result['dataset'][$route];

        return $success;
    }

}
